Documentation
¶
Index ¶
- Constants
- Variables
- type AccountTransferFields
- type AmountFields
- type BalanceFields
- type BillInquiryFields
- type BillPaymentFields
- type BillerFields
- type CardInfoFields
- type CardTransferFields
- type CardsRedis
- type CashInFields
- type CashOutFields
- type ChangePINFields
- type CommonFields
- type ConsumerBalanceFields
- type ConsumerBillInquiryFields
- type ConsumerBillPaymentFields
- type ConsumerCardHolderFields
- type ConsumerCardInfoFields
- type ConsumerCardTransferAndMobileFields
- type ConsumerCardTransferFields
- type ConsumerCommonFields
- type ConsumerCompleteRegistrationFields
- type ConsumerGenerateIPin
- type ConsumerGenerateIPinCompletion
- type ConsumerGenerateVoucherFields
- type ConsumerIPinFields
- type ConsumerIsAliveFields
- type ConsumerPANFromMobileFields
- type ConsumerPurchaseFields
- type ConsumerQRPaymentFields
- type ConsumerQRRefundFields
- type ConsumerRegistrationFields
- type ConsumerSpecificFields
- type ConsumerStatusFields
- type ConsumerWorkingKeyFields
- type ConsumersBillersFields
- type ConsumrAccountTransferFields
- type DefaultValidator
- type DisputeFields
- type EBSMapFields
- type EBSParserFields
- type EntityFields
- type ErrDetails
- type ErrorDetails
- type ErrorResponse
- type GenerateVoucherFields
- type GenericEBSResponseFields
- type ImportantEBSFields
- type IsAliveFields
- type ItemID
- type Merchant
- type MerchantRegistrationFields
- type MiniStatementFields
- type MobileRedis
- type NoebsConfig
- type PayeesListFields
- type PurchaseFields
- type PurchaseWithCashBackFields
- type RefundFields
- type ReverseFields
- type TokenCard
- type ValidationError
- type VoucherCashInFields
- type VoucherCashOutFields
- type WorkingKeyFields
Constants ¶
const ( BadRequest = "BadRequest" ParsingError = "ParsingError" InternalServerError = "InternalServerError" EBSError = "EBSError" )
const ( IsAliveEndpoint = "isAlive" PurchaseEndpoint = "purchase" PurchaseWithCashBackEndpoint = "purchaseWithCashBack" PurchaseMobileEndpoint = "purchaseMobile" ReverseEndpoint = "reverse" BalanceEndpoint = "getBalance" MiniStatementEndpoint = "getMiniStatement" RefundEndpoint = "refund" BillInquiryEndpoint = "getBill" BillPaymentEndpoint = "payBill" BillPrepaymentEndpoint = "prepayBill" AccountTransferEndpoint = "doAccountTransfer" CardTransferEndpoint = "doCardTransfer" NetworkTestEndpoint = "isAlive" WorkingKeyEndpoint = "getWorkingKey" PayeesListEndpoint = "getPayeesList" CashInEndpoint = "cashIn" CashOutEndpoint = "cashOut" GenerateVoucherEndpoint = "generateVoucher" VoucherCashOutWithAmountEndpoint = "cashOutVoucher" VoucherCashInEndpoint = "voucherCashIn" GenerateOTPEndpoint = "generateOTP" ChangePINEndpoint = "changePin" )
const ( PurchaseTransaction = "PurchaseTransaction" PurchaseWithCashBackTransaction = "PurchaseWithCashBack" BillPaymentTransaction = "BillPayment" BillInquiryTransaction = "BillInquiry" CardTransferTransaction = "CardTransfer" WorkingKeyTransaction = "WorkingKeyFields" ChangePINTransaction = "ChangePINTransaction" RefundTransaction = "RefundTransaction" CashInTransaction = "CashInTransaction" CashOutTransaction = "CashOutTransaction" MiniStatementTransaction = "MiniStatementTransaction" IsAliveTransaction = "IsAliveTransaction" BalanceTransaction = "BalanceTransaction" PayeesListTransaction = "PayeesListTransaction" )
const ( EBSIpConsumerTesting = "https://172.16.199.1:8877/QAConsumer/" EBSIp = "https://172.24.160.30:8443/Consumer/" )
const ( ConsumerIsAliveEndpoint = "isAlive" ConsumerWorkingKeyEndpoint = "getPublicKey" ConsumerBalanceEndpoint = "getBalance" ConsumerBillInquiryEndpoint = "getBill" ConsumerBillPaymentEndpoint = "payment" ConsumerCardTransferEndpoint = "doCardTransfer" ConsumerAccountTransferEndpoint = "doAccountTransfer" ConsumerPayeesListEndpoint = "getPayeesList" ConsumerChangeIPinEndpoint = "changeIPin" ConsumerPurchaseEndpoint = "specialPayment" ConsumerStatusEndpoint = "getTransactionStatus" ConsumerQRPaymentEndpoint = "doQRPurchase" ConsumerQRGenerationEndpoint = "doMerchantRegistration" ConsumerQRRefundEndpoint = "doQRRefund" ConsumerPANFromMobile = "checkMsisdnAganistPAN" ConsumerCardInfo = "getCustomerInfo" ConsumerGenerateVoucher = "generateVoucher" // IPIN generation IPinGeneration = "doGenerateIPinRequest" IPinCompletion = "doGenerateCompletionIPinRequest" ConsumerRegister = "register" ConsumerCompleteRegistration = "completeCardRegistration" )
const EBSMerchantIP = "https://172.16.198.14:8888/EBSGateway/"
const EBSMerchantIPTesting = "https://172.16.199.1:8181/QAEBSGateway/"
Variables ¶
var ( ContentTypeErr = customError{/* contains filtered or unexported fields */} EbsGatewayConnectivityErr = customError{/* contains filtered or unexported fields */} )
var EbsFailedTransaction customError
Functions ¶
This section is empty.
Types ¶
type AccountTransferFields ¶
type AccountTransferFields struct {
CommonFields
CardInfoFields
AmountFields
ToAccount string `json:"toAccount" binding:"required"`
}
type AmountFields ¶
type AmountFields struct {
TranAmount float32 `json:"tranAmount" binding:"required" form:"tranAmount"`
TranCurrencyCode string `json:"tranCurrencyCode" form:"tranCurrencyCode"`
}
AmountFields transaction amount data
type BalanceFields ¶
type BalanceFields struct {
CommonFields
CardInfoFields
}
func (*BalanceFields) MustMarshal ¶
func (f *BalanceFields) MustMarshal() []byte
type BillInquiryFields ¶
type BillInquiryFields struct {
CommonFields
CardInfoFields
AmountFields
BillerFields
}
func (*BillInquiryFields) MustMarshal ¶
func (f *BillInquiryFields) MustMarshal() []byte
type BillPaymentFields ¶
type BillPaymentFields struct {
CommonFields
CardInfoFields
AmountFields
BillerFields
}
func (*BillPaymentFields) MustMarshal ¶
func (f *BillPaymentFields) MustMarshal() []byte
type BillerFields ¶
type CardInfoFields ¶
type CardInfoFields struct {
Pan string `json:"PAN" binding:"required" form:"PAN"`
Pin string `json:"PIN" binding:"required" form:"PIN"`
Expdate string `json:"expDate" binding:"required" form:"expDate"`
}
CardInfoFields implements a payment card info
type CardTransferFields ¶
type CardTransferFields struct {
CommonFields
CardInfoFields
AmountFields
ToCard string `json:"toCard" binding:"required"`
}
func (*CardTransferFields) MustMarshal ¶
func (f *CardTransferFields) MustMarshal() []byte
type CardsRedis ¶
type CashInFields ¶
type CashInFields struct {
PurchaseFields
}
func (*CashInFields) MustMarshal ¶
func (f *CashInFields) MustMarshal() []byte
type CashOutFields ¶
type CashOutFields struct {
PurchaseFields
}
func (*CashOutFields) MustMarshal ¶
func (f *CashOutFields) MustMarshal() []byte
type ChangePINFields ¶
type ChangePINFields struct {
CommonFields
CardInfoFields
NewPIN string `json:"newPIN" binding:"required"`
}
func (*ChangePINFields) MustMarshal ¶
func (f *ChangePINFields) MustMarshal() []byte
type CommonFields ¶
type CommonFields struct {
SystemTraceAuditNumber int `json:"systemTraceAuditNumber,omitempty" binding:"required" form:"systemTraceAuditNumber"`
TranDateTime string `json:"tranDateTime,omitempty" binding:"required" form:"tranDateTime"`
TerminalID string `json:"terminalId,omitempty" binding:"required,len=8" form:"terminalId"`
ClientID string `json:"clientId,omitempty" binding:"required" form:"clientId"`
}
type ConsumerBalanceFields ¶
type ConsumerBalanceFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
}
func (*ConsumerBalanceFields) MustMarshal ¶
func (f *ConsumerBalanceFields) MustMarshal() []byte
type ConsumerBillInquiryFields ¶
type ConsumerBillInquiryFields struct {
ConsumerCommonFields
ConsumersBillersFields
ConsumerCardHolderFields
}
func (*ConsumerBillInquiryFields) MustMarshal ¶
func (f *ConsumerBillInquiryFields) MustMarshal() []byte
type ConsumerBillPaymentFields ¶
type ConsumerBillPaymentFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
ConsumersBillersFields
}
func (*ConsumerBillPaymentFields) MustMarshal ¶
func (f *ConsumerBillPaymentFields) MustMarshal() []byte
type ConsumerCardHolderFields ¶
type ConsumerCardHolderFields struct {
Pan string `json:"PAN" form:"PAN" binding:"required"`
Ipin string `json:"IPIN" form:"IPIN" binding:"required"`
ExpDate string `json:"expDate" form:"expDate" binding:"required"`
}
func (*ConsumerCardHolderFields) MustMarshal ¶
func (f *ConsumerCardHolderFields) MustMarshal() []byte
type ConsumerCardInfoFields ¶
type ConsumerCardInfoFields struct {
ConsumerCommonFields
PAN string `json:"PAN" binding:"required"`
}
type ConsumerCardTransferAndMobileFields ¶
type ConsumerCardTransferAndMobileFields struct {
ConsumerCardTransferFields
Mobile string `json:"mobile_number"`
}
type ConsumerCardTransferFields ¶
type ConsumerCardTransferFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
ToCard string `json:"toCard" binding:"required"`
}
func (*ConsumerCardTransferFields) MustMarshal ¶
func (p2p *ConsumerCardTransferFields) MustMarshal() []byte
MustMarshal panics if not able to marshal repsonse
type ConsumerCommonFields ¶
type ConsumerCompleteRegistrationFields ¶
type ConsumerCompleteRegistrationFields struct {
ConsumerCommonFields
OTP string `json:"otp" binding:"required"` // encrypted for fucks sake. fuck ebs
IPIN string `json:"IPIN" binding:"required"` // also encrypted fml forever
ExtraInfo string `json:"extraInfo,omitempty"`
}
type ConsumerGenerateIPin ¶
type ConsumerGenerateIPin struct {
ConsumerCommonFields
Pan string `json:"pan"`
MobileNumber string `json:"phoneNumber" binding:"required"`
Expdate string `json:"expDate"`
}
func (*ConsumerGenerateIPin) MustMarshal ¶
func (gi *ConsumerGenerateIPin) MustMarshal() []byte
type ConsumerGenerateIPinCompletion ¶
type ConsumerGenerateIPinCompletion struct {
ConsumerCommonFields
Pan string `json:"pan" binding:"required"`
Expdate string `json:"expDate" binding:"required"`
Otp string `json:"otp" binding:"required"`
Ipin string `json:"ipin" binding:"required"`
}
func (*ConsumerGenerateIPinCompletion) MustMarshal ¶
func (gip *ConsumerGenerateIPinCompletion) MustMarshal() []byte
type ConsumerGenerateVoucherFields ¶
type ConsumerGenerateVoucherFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
VoucherNumber string `json:"voucherNumber" binding:"required"`
}
type ConsumerIPinFields ¶
type ConsumerIPinFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
NewIPIN string `json:"newIPIN" binding:"required"`
}
func (*ConsumerIPinFields) MustMarshal ¶
func (f *ConsumerIPinFields) MustMarshal() []byte
type ConsumerIsAliveFields ¶
type ConsumerIsAliveFields struct {
ConsumerCommonFields
}
func (*ConsumerIsAliveFields) MustMarshal ¶
func (f *ConsumerIsAliveFields) MustMarshal() []byte
type ConsumerPANFromMobileFields ¶
type ConsumerPANFromMobileFields struct {
ConsumerCommonFields
EntityID string `json:"entityId" binding:"required"`
Last4PAN string `json:"last4PANDigits" binding:"required`
}
type ConsumerPurchaseFields ¶
type ConsumerPurchaseFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
ServiceProviderId string `json:"serviceProviderId" binding:"required"`
}
func (*ConsumerPurchaseFields) MustMarshal ¶
func (f *ConsumerPurchaseFields) MustMarshal() []byte
type ConsumerQRPaymentFields ¶
type ConsumerQRPaymentFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
MerchantID string `json:"merchantID" binding:"required"`
}
func (*ConsumerQRPaymentFields) MustMarshal ¶
func (f *ConsumerQRPaymentFields) MustMarshal() []byte
type ConsumerQRRefundFields ¶
type ConsumerQRRefundFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
OriginalTranUUID string `json:"originalTranUUID" binding:"required"`
}
func (*ConsumerQRRefundFields) MustMarshal ¶
func (f *ConsumerQRRefundFields) MustMarshal() []byte
type ConsumerRegistrationFields ¶
type ConsumerRegistrationFields struct {
ConsumerCommonFields
EntityFields
RegistrationType string `json:"registrationType"`
PhoneNo string `json:"phoneNo"`
}
ConsumerRegistrationFields the first step in card issuance
type ConsumerSpecificFields ¶
type ConsumerSpecificFields struct {
UUID string `json:"UUID" form:"UUID" binding:"required,len=36"`
Mbr string `json:"mbr,omitempty" form:"mbr"`
Ipin string `json:"IPIN" form:"IPIN" binding:"required"`
PAN string `json:"PAN"`
ExpDate string `json:"expDate"`
PanCategory string `json:"panCategory"`
FromAccountType string `json:"fromAccountType" form:"fromAccountType"`
ToAccountType string `json:"toAccountType" form:"toAccountType"`
AccountCurrency string `json:"accountCurrency" form:"accountCurrency"`
AcqTranFee float32 `json:"acqTranFee" form:"acqTranFee"`
IssuerTranFee float32 `json:"issuerTranFee" form:"issuerTranFee"`
// billers
BillInfo string `json:"billInfo" form:"billInfo"`
Payees string `json:"payees" form:"payees"`
// tran time
OriginalTranUUID string `json:"originalTranUUID" form:"originalTranUUID"`
OriginalTranDateTime string `json:"originalTranDateTime" form:"originalTranDateTime"`
// User settings
Username string `json:"userName" Form:"userName"`
UserPassword string `json:"userPassword" form:"userPassword"`
// Entities
EntityType string `json:"entityType" form:"entityType"`
EntityId string `json:"entityId" form:"entityId"`
EntityGroup string `json:"entityGroup" form:"entityGroup"`
PubKeyValue string `json:"pubKeyValue" form:"pubKeyValue"`
Email string `json:"email" form:"email"`
ExtraInfo string `json:"extraInfo" form:"extraInfo"`
PhoneNo string `json:"phoneNo" form:"phoneNo"`
NewIpin string `json:"newIPIN" form:"newIPIN"`
NewUserPassword string `json:"newUserPassword" form:"newUserPassword"`
SecurityQuestion string `json:"securityQuestion" form:"securityQuestion"`
SecurityQuestionAnswer string `json:"securityQuestionAnswer" form:"securityQuestionAnswer"`
AdminUserName string `json:"adminUserName" form:"adminUserName"`
// other fields
OriginalTransaction map[string]interface{} `json:"originalTransaction" form:"originalTransaction"`
OriginalTranType string `json:"originalTranType" form:"originalTranType"`
FinancialInstitutionID string `json:"financialInstitutionId" form:"financialInstitutionId"`
}
type ConsumerStatusFields ¶
type ConsumerStatusFields struct {
ConsumerCommonFields
OriginalTranUUID string `json:"originalTranUUID" binding:"required"`
}
func (*ConsumerStatusFields) MustMarshal ¶
func (f *ConsumerStatusFields) MustMarshal() []byte
type ConsumerWorkingKeyFields ¶
type ConsumerWorkingKeyFields struct {
ConsumerCommonFields
}
func (*ConsumerWorkingKeyFields) MustMarshal ¶
func (f *ConsumerWorkingKeyFields) MustMarshal() []byte
type ConsumersBillersFields ¶
type ConsumersBillersFields struct {
PayeeId string `json:"payeeId" form:"payeeId" binding:"required"`
PaymentInfo string `json:"paymentInfo" form:"paymentInfo" binding:"required"`
}
func (*ConsumersBillersFields) MustMarshal ¶
func (f *ConsumersBillersFields) MustMarshal() []byte
type ConsumrAccountTransferFields ¶
type ConsumrAccountTransferFields struct {
ConsumerCommonFields
ConsumerCardHolderFields
AmountFields
ToAccount string `json:"toAccount" binding:"required"`
}
type DefaultValidator ¶
type DefaultValidator struct {
// contains filtered or unexported fields
}
func (*DefaultValidator) Engine ¶
func (v *DefaultValidator) Engine() interface{}
func (*DefaultValidator) ValidateStruct ¶
func (v *DefaultValidator) ValidateStruct(obj interface{}) error
type DisputeFields ¶
type DisputeFields struct {
Time string `json:"time,omitempty"`
Service string `json:"service,omitempty"`
UUID string `json:"uuid,omitempty"`
STAN int `json:"stan,omitempty"`
Amount float32 `json:"amount,omitempty"`
}
func (*DisputeFields) New ¶
func (d *DisputeFields) New(f EBSParserFields) *DisputeFields
type EBSMapFields ¶
type EBSMapFields struct {
// these
Balance map[string]interface{} `json:"balance,omitempty"`
PaymentInfo string `json:"paymentInfo,omitempty"`
BillInfo map[string]interface{} `json:"billInfo,omitempty"`
}
special case to handle ebs non-DB-able fields e.g., hashmaps and other complex types
type EBSParserFields ¶
type EBSParserFields struct {
EBSMapFields
GenericEBSResponseFields
}
you have to update this to account for the non-db-able fields
func EBSHttpClient ¶
func EBSHttpClient(url string, req []byte) (int, EBSParserFields, error)
EBSHttpClient the client to interact with EBS
func (*EBSParserFields) MarshalBinary ¶
func (p *EBSParserFields) MarshalBinary() ([]byte, error)
To allow Redis to use this struct directly in marshaling
func (*EBSParserFields) UnmarshalBinary ¶
func (p *EBSParserFields) UnmarshalBinary(data []byte) error
To allow Redis to use this struct directly in marshaling
type EntityFields ¶
type ErrDetails ¶
type ErrDetails map[string]interface{}
func ErrorToString ¶
func ErrorToString(e validator.FieldError) ErrDetails
type ErrorDetails ¶
type ErrorResponse ¶
type ErrorResponse struct {
ErrorDetails
}
type GenerateVoucherFields ¶
type GenerateVoucherFields struct {
PurchaseFields
PhoneNumber string `json:"phoneNumber" binding:"required"`
}
type GenericEBSResponseFields ¶
type GenericEBSResponseFields struct {
TerminalID string `json:"terminalId,omitempty"`
SystemTraceAuditNumber int `json:"systemTraceAuditNumber,omitempty"`
ClientID string `json:"clientId,omitempty"`
PAN string `json:"PAN,omitempty"`
ServiceID string `json:"serviceId,omitempty"`
TranAmount float32 `json:"tranAmount,omitempty"`
PhoneNumber string `json:"phoneNumber,omitempty"`
FromAccount string `json:"fromAccount,omitempty"`
ToAccount string `json:"toAccount,omitempty"`
FromCard string `json:"fromCard,omitempty"`
ToCard string `json:"toCard,omitempty"`
OTP string `json:"otp,omitempty"`
OTPID string `json:"otpId,omitempty"`
TranCurrencyCode string `json:"tranCurrencyCode,omitempty"`
EBSServiceName string `json:"-,omitempty"`
WorkingKey string `json:"workingKey,omitempty" gorm:"-"`
PayeeID string `json:"payeeId,omitempty"`
// Consumer fields
PubKeyValue string `json:"pubKeyValue,omitempty" form:"pubKeyValue"`
UUID string `json:"UUID,omitempty" form:"UUID"`
ResponseMessage string `json:"responseMessage,omitempty"`
ResponseStatus string `json:"responseStatus,omitempty"`
ResponseCode int `json:"responseCode"`
ReferenceNumber string `json:"referenceNumber,omitempty"`
ApprovalCode string `json:"approvalCode,omitempty"`
VoucherNumber int `json:"voucherNumber,omitempty"`
MiniStatementRecords []map[string]interface{} `json:"miniStatementRecords,omitempty" gorm:"-"`
DisputeRRN string `json:"DisputeRRN,omitempty"`
AdditionalData string `json:"additionalData,omitempty"`
TranDateTime string `json:"tranDateTime,omitempty"`
TranFee *float32 `json:"tranFee,omitempty"`
AdditionalAmount *float32 `json:"additionalAmount,omitempty"`
AcqTranFee *float32 `json:"acqTranFee,omitempty"`
IssTranFee *float32 `json:"issuerTranFee,omitempty"`
TranCurrency string `json:"tranCurrency,omitempty"`
// QR payment fields
MerchantID string `json:"merchantID,omitempty"`
GeneratedQR string `json:"generatedQR,omitempty"`
Bank string `json:"bank,omitempty"`
Name string `json:"name,omitempty"`
CardType string `json:"card_type,omitempty"`
LastPAN string `json:"last4PANDigits,omitempty"`
}
GenericEBSResponseFields represent EBS response
func (*GenericEBSResponseFields) MaskPAN ¶
func (res *GenericEBSResponseFields) MaskPAN()
MaskPAN returns the last 4 digit of the PAN. We shouldn't care about the first 6
type ImportantEBSFields ¶
type ImportantEBSFields struct {
}
type IsAliveFields ¶
type IsAliveFields struct {
CommonFields
}
func (*IsAliveFields) MustMarshal ¶
func (f *IsAliveFields) MustMarshal() []byte
type Merchant ¶
type Merchant struct {
MerchantID string `json:"merchant_id" form:"merchant_id" gorm:"index"`
MerchantName string `json:"name" form:"name" binding:"required" gorm:"column:name"`
MerchantCity string `json:"city" form:"city" binding:"required" gorm:"column:city"`
MerchantMobileNumber string `json:"mobile" form:"mobile" binding:"required,max=10" gorm:"column:mobile; index:,unqiue"`
IDType int `json:"id_type" form:"id_type" binding:"required" gorm:"column:id_type"`
IDNo string `json:"id_no" form:"id_no" binding:"required" gorm:"column:id_no"`
TerminalID string `json:"-" gorm:"-"`
PushID string `json:"push_id" gorm:"column:push_id"`
Password string `json:"password"`
IsVerifed bool `json:"is_verified"`
BillerID string `json:"biller_id"`
EBSBiller string `json:"ebs_biller"`
CardNumber string `json:"card" gorm:"column:card"`
Hooks string `json:"hooks" gorm:"hooks"`
URL string `json:"url" gorm:"url"`
}
Merchant constructs ebs qualfied merchant
func (*Merchant) MarshalBinary ¶
type MerchantRegistrationFields ¶
type MerchantRegistrationFields struct {
ConsumerCommonFields
Merchant
//allowed fields are CARD only for now. CF ebs document
MerchantAccountType string `json:"merchantAccountType" binding:"required"`
// this is the pan
MerchantAccountReference string `json:"merchantAccountReference" binding:"required"`
ExpDate string `json:"expDate" binding:"required"`
}
func (*MerchantRegistrationFields) MustMarshal ¶
func (f *MerchantRegistrationFields) MustMarshal() []byte
type MiniStatementFields ¶
type MiniStatementFields struct {
CommonFields
CardInfoFields
}
func (*MiniStatementFields) MustMarshal ¶
func (f *MiniStatementFields) MustMarshal() []byte
type MobileRedis ¶
type NoebsConfig ¶
var SecretConfig NoebsConfig
type PayeesListFields ¶
type PayeesListFields struct {
CommonFields
}
type PurchaseFields ¶
type PurchaseFields struct {
WorkingKeyFields
CardInfoFields
AmountFields
}
func (*PurchaseFields) MustMarshal ¶
func (f *PurchaseFields) MustMarshal() []byte
type PurchaseWithCashBackFields ¶
type PurchaseWithCashBackFields struct {
PurchaseFields
}
func (*PurchaseWithCashBackFields) MustMarshal ¶
func (f *PurchaseWithCashBackFields) MustMarshal() []byte
type RefundFields ¶
type RefundFields struct {
PurchaseFields
OriginalSTAN int `json:"originalSystemTraceAuditNumber" binding:"required"`
}
func (*RefundFields) MustMarshal ¶
func (f *RefundFields) MustMarshal() []byte
type ReverseFields ¶
type ReverseFields struct {
PurchaseFields
}
func (*ReverseFields) MustMarshal ¶
func (f *ReverseFields) MustMarshal() []byte
type TokenCard ¶
type TokenCard struct {
CardInfoFields
Fingerprint string `json:"fingerprint" binding:"required"`
}
type ValidationError ¶
type VoucherCashInFields ¶
type VoucherCashInFields struct {
CommonFields
VoucherNumber string `json:"voucherNumber" binding:"required"`
CardInfoFields
}
type VoucherCashOutFields ¶
type VoucherCashOutFields struct {
CommonFields
PhoneNumber string `json:"phoneNumber" binding:"required"`
VoucherNumber string `json:"voucherNumber" binding:"required"`
}
type WorkingKeyFields ¶
type WorkingKeyFields struct {
CommonFields
}
func (*WorkingKeyFields) MustMarshal ¶
func (f *WorkingKeyFields) MustMarshal() []byte
Click to show internal directories.
Click to hide internal directories.